aboutsummaryrefslogtreecommitdiffstats
path: root/packages/0x.js/src/utils/promisify.ts
diff options
context:
space:
mode:
authorLeonid Logvinov <logvinov.leon@gmail.com>2017-12-05 22:01:24 +0800
committerLeonid Logvinov <logvinov.leon@gmail.com>2017-12-05 22:01:24 +0800
commitf88ecaa035352a511fbee1ff1846cdacd03ca169 (patch)
tree8510a912e3f2877274a998d95c64759ac0d518e7 /packages/0x.js/src/utils/promisify.ts
parentc0cf47138ec2efe4c0a27de9a503bb0d74d99d5f (diff)
downloaddexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar.gz
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar.bz2
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar.lz
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar.xz
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.tar.zst
dexon-sol-tools-f88ecaa035352a511fbee1ff1846cdacd03ca169.zip
Fix a comment
Diffstat (limited to 'packages/0x.js/src/utils/promisify.ts')
-rw-r--r--packages/0x.js/src/utils/promisify.ts10
1 files changed, 5 insertions, 5 deletions
diff --git a/packages/0x.js/src/utils/promisify.ts b/packages/0x.js/src/utils/promisify.ts
index 49024c0e9..c114cf32f 100644
--- a/packages/0x.js/src/utils/promisify.ts
+++ b/packages/0x.js/src/utils/promisify.ts
@@ -1,23 +1,23 @@
import * as _ from 'lodash';
/**
* Transforms callback-based function -- func(arg1, arg2 .. argN, callback) -- into
* an ES6-compatible Promise. Promisify provides a default callback of the form (error, result)
* and rejects when `error` is not null. You can also supply settings object as the second argument.
*/
export function promisify<T>(
originalFn: (
...args: any[],
// HACK: This can't be properly typed without variadic kinds https://github.com/Microsoft/TypeScript/issues/5453
) => void,
- target?: any,
+ thisArg?: any,
): (...callArgs: any[]) => Promise<T> {
const promisifiedFunction = async (...callArgs: any[]): Promise<T> => {
return new Promise<T>((resolve, reject) => {
const callback = (err: Error|null, data?: T) => {
_.isNull(err) ? resolve(data) : reject(err);
};
- originalFn.apply(target, [...callArgs, callback]);
+ originalFn.apply(thisArg, [...callArgs, callback]);
});
};
return promisifiedFunction;
@@ -1,23 +1,23 @@
import * as _ from 'lodash';
/**
- * Transforms callback-based function -- func(arg1, arg2 .. argN, callback) -- into
- * an ES6-compatible Promise. Promisify provides a default callback of the form (error, result)
- * and rejects when `error` is not null. You can also supply settings object as the second argument.
+ * Transforms callback-based function -- func(arg1, arg2 .. argN, callback) -- into an ES6-compatible Promise.
+ * Promisify provides a default callback of the form (error, result) and rejects when `error` is not null. You can also
+ * supply thisArg object as the second argument which will be passed to `apply`.
*/
export function promisify<T>(